unit u_extresbutton;

{$IFDEF FPC}
{$mode Delphi}
{$ENDIF}


interface

uses
  Classes, SysUtils, LResources, Forms, Controls, Graphics, Dialogs,
  u_buttons_defs;

type

  { TExtResButton }

  TExtResButton = class(TFWButton)
  private
    FResource : String;
    FPictCount : Integer;
    FPictNum : Integer;
    procedure p_setResource  ( const AValue : String  );
    procedure p_setPictCount ( const AValue : Integer );
    procedure p_setPictNum   ( const AValue : Integer );
  protected
    procedure p_RedrawPictFromPictures ( const AResource : String ); virtual;

  public
    constructor Create ( AOwner : TComponent ) ; override;
  published
    property Resource  : String  read FResource  write p_setResource;
    property PictCount : Integer read FPictCount write p_setPictCount default 1;
    property PictNum   : Integer read FPictNum   write p_setPictNum   default 0;
  end;


implementation


{ TExtResButton }

procedure TExtResButton.p_setResource(const AValue: String);
begin
  if AValue <> FResource Then
   try
     p_RedrawPictFromPictures(AValue);
     FResource:=AValue;
   except
     Glyph.Clear;
   end;
end;

procedure TExtResButton.p_setPictCount(const AValue: Integer);
begin
  if AValue < 1 Then
   Exit;
  if AValue <> FPictCount then
   try
     FPictCount:=AValue;
     p_RedrawPictFromPictures(FResource);
   except
   end;
end;

procedure TExtResButton.p_RedrawPictFromPictures( const AResource : String );
var FPicture : TPicture;
begin
  if AResource = '' Then
   Exit;
  FPicture := TPicture.Create;
  with FPicture do
   try
     LoadFromLazarusResource(AResource);
     Glyph.Bitmap.Width:=Width div FPictCount;
     Glyph.Bitmap.Height:=FPicture.Height;
     Glyph.Bitmap.Canvas.Draw(-Glyph.Width*FPictNum,0,FPicture.Bitmap);
   Finally
     FPicture.Destroy;
   end;
end;

procedure TExtResButton.p_setPictNum(const AValue: Integer);
begin
  if AValue < 0 Then
   Exit;
  if AValue <> FPictNum then
   try
     FPictNum:=AValue;
     p_RedrawPictFromPictures(FResource);
   except
   end;
end;

constructor TExtResButton.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FPictNum:=0;
  FPictCount:=1;
  FResource:='';
end;

end.
